package model

import "encoding/json"

type SpeechDomainParams struct {
	SpeechWsResp *SpeechWsResp
	Query        string
	RequestId    string
	Mac          string
	Domain       string
	Mid          string
	MidType      string
	SessionId    string
	HomeId       string
	AppKey       string
}

type SpeechWsResp struct {
	RequestId string `json:"requestId"`
	Dm        *struct {
		Param *struct {
			Period    string `json:"period"`
			Object    string `json:"object"`
			Time      string `json:"time"`
			Date      string `json:"date"`
			Operation string `json:"operation"`
			Event     string `json:"event"`
			Repeat    string `json:"repeat"`
			Operate   string `json:"operate"`
			Number    string `json:"number"`
		} `json:"param"`
		IntentName  string `json:"intentName"`
		Input       string `json:"input"`
		IntentId    string `json:"intentId"`
		RunSequence string `json:"runSequence"`
		Widget      *struct {
			WidgetName string `json:"widgetName"`
			SubTitle   string `json:"subTitle"`
			Name       string `json:"name"`
			Extra      *struct {
				ContentTranslation string      `json:"content_translation"`
				Title              string      `json:"title"`
				Result             interface{} `json:"result"`
			} `json:"extra"`
			Title   string `json:"title"`
			Buttons []struct {
				Name string `json:"name"`
			} `json:"buttons"`
			DuiWidget    string      `json:"duiWidget"`
			Type         string      `json:"type"`
			Count        int         `json:"count"`
			CurrentPage  int         `json:"currentPage"`
			TotalPages   int         `json:"totalPages"`
			ItemsPerPage int         `json:"itemsPerPage"`
			Match        interface{} `json:"match"`
			Content      interface{} `json:"content"`
			//Content      []struct {
			//	LinkUrl    string `json:"linkUrl"`
			//	ImageUrl   string `json:"imageUrl"`
			//	SubTitle   string `json:"subTitle"`
			//	Album      string `json:"album"`
			//	Parameters struct {
			//		ResType string `json:"resType"`
			//	} `json:"parameters"`
			//	Title  string `json:"title"`
			//	Author string `json:"author"`
			//	Text   string `json:"text"`
			//	Extra  struct {
			//		Dynasty string `json:"dynasty"`
			//		ResType string `json:"resType"`
			//	} `json:"extra"`
			//} `json:"content"`
		} `json:"widget"`
		Nlg              string `json:"nlg"`
		Task             string `json:"task"`
		ShouldEndSession bool   `json:"shouldEndSession"`
		Api              string `json:"api"`
		Command          *struct {
			Param *struct {
				Volume     string `json:"volume"`
				Mode       string `json:"mode"`
				Object     string `json:"object"`
				Extra      string `json:"extra"`
				Version    string `json:"version"`
				Song       string `json:"song"`
				Singer     string `json:"singer"`
				Emotion    string `json:"emotion"`
				Album      string `json:"album"`
				Language   string `json:"language"`
				Age        string `json:"age"`
				Instrument string `json:"instrument"`
				Author     string `json:"author"`
				Composer   string `json:"composer"`
				People     string `json:"people"`
				Area       string `json:"area"`
				Theme      string `json:"theme"`
				Style      string `json:"style"`
				Toplist    string `json:"toplist"`
				AgeRange   string `json:"ageRange"`
			} `json:"param"`
			Api string `json:"api"`
		} `json:"command"`
	} `json:"dm"`
	SpeakUrl  string `json:"speakUrl"`
	SkillId   string `json:"skillId"`
	Skill     string `json:"skill"`
	ContextId string `json:"contextId"`
	Error     *struct {
		ErrId  interface{} `json:"errId"`
		ErrMsg string      `json:"errMsg"`
	} `json:"error"`
	RecordId  string `json:"recordId"`
	SessionId string `json:"sessionId"`
}

type Content struct {
	LinkUrl    string `json:"linkUrl"`
	ImageUrl   string `json:"imageUrl"`
	SubTitle   string `json:"subTitle"`
	Album      string `json:"album"`
	Parameters struct {
		ResType string `json:"resType"`
	} `json:"parameters"`
	Title  string `json:"title"`
	Author string `json:"author"`
	Text   string `json:"text"`
	Extra  struct {
		Dynasty string `json:"dynasty"`
		ResType string `json:"resType"`
		Source  string `json:"source"`
		NewsId  string `json:"news_id"`
	} `json:"extra"`
}

type Result struct {
	Day      int    `json:"day"`
	Title    string `json:"title"`
	Month    int    `json:"month"`
	SubTitle string `json:"subTitle"`
	Date     string `json:"date"`
	Year     int    `json:"year"`
	Event    string `json:"event"`
}

type ExtraParams struct {
	Content json.RawMessage `json:"content"`
}
